@@ -60,17 +60,18 @@ def get_table(args) -> List[dict]:
     )
 
     folders = group_by_folder(args, media)
-    return sorted(folders, key=lambda x: x["count_deleted"] if args.sort_by_deleted else x["size"])
+    return sorted(folders, key=lambda x: x["count_deleted"] if args.sort_by_deleted else x["size"] / x["count"])
 
 
 def parse_args() -> argparse.Namespace:
     parser = argparse.ArgumentParser()
-    parser.add_argument("database")
     parser.add_argument("--sort-by-deleted", action="store_true")
     parser.add_argument("--limit", "-L", "-l", "-queue", "--queue", default="4000")
     parser.add_argument("--lower", default=4, type=int, help="Number of files per folder lower limit")
     parser.add_argument("--upper", default=4000, type=int, help="Number of files per folder upper limit")
     parser.add_argument("--verbose", "-v", action="count", default=0)
+
+    parser.add_argument("database")
     args = parser.parse_args()
     args.db = db.connect(args)
     log.info(utils.dict_filter_bool(args.__dict__))
