@@ -16,6 +16,8 @@ yt_recoverable_errors = re.compile(
 .*geolocation
 .*your country
 .*No such file or directory
+.*The downloaded file is empty
+.*Invalid data found
 .*fragment 1 not found
 .*HTTP Error 429
 .*HTTP Error 400
@@ -159,6 +161,7 @@ yt_unrecoverable_errors = re.compile(
 .*\[youtube:truncated_url\]
 .*: This video is not available.\$
 .*Video unavailable. This video is not available\$
+.*This article does not contain a video
 .*Resource temporarily unavailable
 .*This video is unavailable
 .*No video could be found in this
@@ -170,6 +173,7 @@ yt_unrecoverable_errors = re.compile(
 .*not a video\$
 .*The page doesn't contain any tracks
 .*removed by the uploader
+.*blocked due to author's rights infingement
 .*blocked it on copyright grounds\$
 .*uploader has closed their.*account
 .*account has been terminated because we received multiple
